package models;

import net.sf.oval.constraint.Length;
import net.sf.oval.constraint.NotNull;
import play.data.validation.Email;
import play.data.validation.Min;
import play.data.validation.Required;
import play.db.jpa.Model;
import play.libs.Crypto;

import javax.persistence.Entity;
import javax.persistence.PrePersist;
import java.util.Date;
import java.util.List;

/**
 * Dominik Dorn
 * 0626165
 * dominik.dorn@tuwien.ac.at
 */
@Entity
public class Member extends Model {

    @NotNull
    @Length(min = 3, max = 50)
    @Required
    public String firstname;
    @NotNull
    @Length(min = 3, max = 50)
    @Required
    public String lastname;

    public static List<Member> findByType(TYPE type) {
     return find("byType", type).fetch();
    }

    public enum TYPE {
        FIRST,
        ORDENTLICH,
        AUSSERORDENTLICH,
        LAST
    }

    @NotNull
    public TYPE type;

    @Email
    public String email;

    public String password;

    public Date registrationDate;

    @PrePersist
    public void prePersist()
    {
        registrationDate = new Date();

        password = Crypto.sign(password);
        if(type == null)
            type = TYPE.AUSSERORDENTLICH;
    }

}
